﻿using Carmenta.Engine;

using CarmentaWpfClient.Messages;

using CommunityToolkit.Mvvm.ComponentModel;
using CommunityToolkit.Mvvm.Messaging;

using System.Collections.Generic;
using System.Linq;

namespace CarmentaWpfClient.Models
{
    public class LayerModel : ObservableObject
    {
        private readonly Layer _layer;

        public LayerModel(Layer layer)
        {
            _layer = layer;

            if (layer is LayerSet layerSet)
            {
                Children = layerSet
                    .Layers
                    .Select(x => new LayerModel(x))
                    .ToList();
            }
        }

        public List<LayerModel> Children { get; private set; } = new();

        public bool Enabled
        {
            get => _layer.Enabled;
            set => SetProperty(_layer.Enabled, value, x =>
            {
                _layer.Enabled = x;
                WeakReferenceMessenger.Default.Send(new UpdateViewMessage());
            });
        }

        public string Name => _layer.Name;
    }
}
