﻿using CommunityToolkit.Mvvm.ComponentModel;
using CommunityToolkit.Mvvm.Input;

using System.Windows.Controls;

namespace CarmentaWpfClient.ViewModels
{
    public partial class DrawerMenuViewModel(
        LayerControlViewModel _layerControlViewModel,
        ToolsMenuViewModel _toolsMenuViewModel,
        TacticalSymbolsMenuViewModel _tacticalSymbolsMenuViewModel) : ObservableObject
    {
        [ObservableProperty]
        private object? _currentViewModel;

        private bool _isOpen;

        public bool IsOpen
        {
            get => _isOpen;
            set => SetProperty(ref _isOpen, value);
        }

        [RelayCommand]
        public void ButtonClicked() => IsOpen = !IsOpen;

        [RelayCommand]
        private void SelectionChanged(SelectionChangedEventArgs? e)
        {
            if (e is null) return;
            if (e.AddedItems.Count == 0)
            {
                CurrentViewModel = null;
                return;
            }

            if (e.AddedItems[0] is ListBoxItem listBoxItem)
            {
                var tag = listBoxItem.Tag.ToString();

                CurrentViewModel = tag switch
                {
                    "layers" => _layerControlViewModel,
                    "tools" => _toolsMenuViewModel,
                    "tactical" => _tacticalSymbolsMenuViewModel,
                    _ => null
                };
            }
        }
    }
}
