﻿using Carmenta.Engine;

using CarmentaWpfClient.Messages;

using CommunityToolkit.Mvvm.ComponentModel;
using CommunityToolkit.Mvvm.Input;
using CommunityToolkit.Mvvm.Messaging;

using System.Collections.Generic;
using System.Windows;

namespace CarmentaWpfClient.ViewModels
{
    public partial class TacticalSymbolsMenuViewModel : ObservableObject
    {
        private readonly SymbolStandard _symbolStandard = SymbolStandard.MilStd2525D;
        private SymbolMetadata? _currentSymbolMetadata;
        private string _affiliation = "Friend";

        public IEnumerable<SymbolMetadata> Symbols => _symbolStandard.Metadata.ChildSymbols;

        public string Affiliation
        {
            get => _affiliation; set
            {
                _affiliation = value;

                SendUpdateMessage();
            }
        }

        [RelayCommand]
        public void SelectionChanged(RoutedPropertyChangedEventArgs<object>? args)
        {
            if (args?.NewValue is not SymbolMetadata symbolMetadata)
                return;

            _currentSymbolMetadata = symbolMetadata;

            SendUpdateMessage();
        }

        private void SendUpdateMessage()
        {
            if (_currentSymbolMetadata is not null)
                WeakReferenceMessenger.Default.Send(new SymbolSelectedMessage(_currentSymbolMetadata, Affiliation));
        }
    }
}
