﻿using Microsoft.AspNetCore.SignalR;
using StreamingService.Utils;
using System.Threading.Channels;

using SerializedFeature = byte[];

namespace StreamingService;

public class CommunicationHub(StreamingRepository<Guid, SerializedFeature> repository) : Hub
{
    public void UpdateFeature(Guid id, SerializedFeature value)
        => repository.Update(id, value);

    public void AddFeature(Guid id, SerializedFeature value)
        => repository.Add(id, value);

    public void RemoveFeature(Guid id) =>
        repository.Remove(id);

    public ChannelReader<(Guid Id, SerializedFeature Buffer)> AddedStream()
        => repository.AddedStream.AsChannelReader();

    public ChannelReader<(Guid, SerializedFeature)> UpdateStream()
        => repository.UpdateStream.AsChannelReader();

    public ChannelReader<Guid> RemoveStream()
        => repository.RemovedStream.AsChannelReader();

    public List<(Guid id, SerializedFeature Buffer)> AllFeatures() =>
        repository.Objects.ToList();
}