﻿using System.Threading.Channels;

namespace StreamingService.Utils;

public static class Extensions
{
    public static ChannelReader<T> AsChannelReader<T>(this IObservable<T> observable)
    {
        var channel = Channel.CreateUnbounded<T>();

        IDisposable disposable = observable.Subscribe(
            value => channel.Writer.TryWrite(value),
            error => channel.Writer.TryComplete(error),
            () => channel.Writer.TryComplete());

        channel.Reader.Completion.ContinueWith(_ => disposable.Dispose());
        return channel.Reader;
    }
}